/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 1998  Lionel ULMER
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __COMMON_H__
#define __COMMON_H__

#include <stdio.h>
#include <stdlib.h>

#include <gtk/gtk.h>

#include "db_conn.h"
#include "config.h"

#define APPNAME "GtkSQL"
#define VERSION "0.3"
#define MAIL    "bbrox@multimania.com"
#define URL     "http://www.multimania.com/bbrox/GtkSQL/"

extern DBConnection *conn;

/* GtkNotebookPage *gtk_notebook_get_bookpage(GtkNotebook *notebook,
   gint position) ;
   GtkWidget *gtk_notebook_get_page(GtkNotebook *notebook,
   gint position) ;
   GtkWidget *gtk_notebook_get_tab_label(GtkNotebook *notebook,
   gint position) ;
   GtkWidget *gtk_notebook_get_menu_label(GtkNotebook *notebook,
   gint position) ; */

void UpdateButtonSensitivity() ;

#endif  __COMMON_H__
